@@ -1,7 +1,7 @@
 import os
 
 from neuroml.hdf5.NetworkContainer import *
-from neuromllite.BaseTypes import NetworkReader
+from neuromllite import NetworkReader
 
 from neuromllite.utils import print_v, load_json
 
@@ -101,7 +101,7 @@ class PsyNeuLinkReader(NetworkReader):
                     pop_id = node._v_name.replace('-','_')
                     self.current_population = pop_id
                     self.pop_locations[self.current_population] = {}
-                    
+
                 if g._v_name=='connectivity':
                     self.pre_pop = node._v_name.replace('-','_')
                     self.post_pop=None
@@ -112,17 +112,17 @@ class PsyNeuLinkReader(NetworkReader):
                 elif self.pre_pop!=None and self.post_pop!=None:
                     #print("Conn3 %s -> %s"%(self.pre_pop,self.post_pop))
                     pass
-                    
+
                 self.parse_group(node)
 
             if self._is_dataset(node):
                 self.parse_dataset(node)
-                
+
         self.current_population = None
-        
+
 
     def _is_dataset(self, node):
-          return node._c_classid == 'ARRAY' or node._c_classid == 'CARRAY'   
+          return node._c_classid == 'ARRAY' or node._c_classid == 'CARRAY'
 
 
     def _is_interneuron(self, pop_id):
@@ -134,15 +134,15 @@ class PsyNeuLinkReader(NetworkReader):
 
     def parse_dataset(self, d):
         #print_v("Parsing dataset/array: "+ str(d))
-        
+
         # Population
         if self.current_population and d.name=='locations':
-            
+
             perc_cells = self.parameters['percentage_cells_per_pop'] if 'percentage_cells_per_pop' in self.parameters else 100
             if perc_cells>100: perc_cells = 100
-            
+
             size = max(0,int((perc_cells/100.)*d.shape[0]))
-            
+
             if size>0:
                 properties = {}
                 if self._is_interneuron(self.current_population):
@@ -152,7 +152,7 @@ class PsyNeuLinkReader(NetworkReader):
                     properties['radius'] = 10
                     type='E'
                 properties['type'] = type
-                    
+
                 layer = self.current_population.split('_')[0]
                 properties['region'] = layer
                 try:
@@ -169,14 +169,14 @@ class PsyNeuLinkReader(NetworkReader):
                     if layer == 'L6':
                         if type=='E': color = occ.L6_PRINCIPAL_CELL
                         if type=='I': color = occ.L6_INTERNEURON
-                            
+
                     properties['color'] = color
                 except:
                     # Don't worry about it, it's just metadata
                     pass
-                
+
                 component_obj = None
-                
+
                 if self.parameters['DEFAULT_CELL_ID'] in self.component_objects:
                     component_obj = self.component_objects[self.parameters['DEFAULT_CELL_ID']]
                 else:
@@ -184,15 +184,15 @@ class PsyNeuLinkReader(NetworkReader):
                         def_cell_info = self.parameters['cell_info'][self.parameters['DEFAULT_CELL_ID']]
                         if def_cell_info.neuroml2_source_file:
                             from pyneuroml import pynml
-                            nml2_doc = pynml.read_neuroml2_file(def_cell_info.neuroml2_source_file, 
+                            nml2_doc = pynml.read_neuroml2_file(def_cell_info.neuroml2_source_file,
                                                     include_includes=True)
                             component_obj = nml2_doc.get_by_id(self.parameters['DEFAULT_CELL_ID'])
                             print_v("Loaded NeuroML2 object %s from %s "%(component_obj,def_cell_info.neuroml2_source_file))
                             self.component_objects[self.parameters['DEFAULT_CELL_ID']] = component_obj
-                        
 
-                self.handler.handle_population(self.current_population, 
-                                         self.parameters['DEFAULT_CELL_ID'], 
+
+                self.handler.handle_population(self.current_population,
+                                         self.parameters['DEFAULT_CELL_ID'],
                                          size,
                                          component_obj=component_obj,
                                          properties=properties)
@@ -207,21 +207,21 @@ class PsyNeuLinkReader(NetworkReader):
                         z = row[2]
                         self.pop_locations[self.current_population][i]=(x,y,z)
                         self.handler.handle_location(i, self.current_population, self.parameters['DEFAULT_CELL_ID'], x, y, z)
-                    
-                
+
+
         # Projection
         elif self.pre_pop!=None and self.post_pop!=None:
-            
+
             proj_id = 'Proj__%s__%s'%(self.pre_pop,self.post_pop)
             synapse = 'gaba'
             if 'PC' in self.pre_pop or 'SS' in self.pre_pop: # TODO: better choice between E/I cells
                 synapse = 'ampa'
-                
+
             (ii, jj) = np.nonzero(d)
             conns_here = False
             pre_num = len(self.pop_locations[self.pre_pop]) if self.pre_pop in self.pop_locations else 0
             post_num = len(self.pop_locations[self.post_pop]) if self.post_pop in self.pop_locations else 0
-            
+
             if pre_num>0 and post_num>0:
                 for index in range(len(ii)):
                     if ii[index]<pre_num and \
@@ -231,9 +231,9 @@ class PsyNeuLinkReader(NetworkReader):
 
                 if conns_here:
                     print_v("Conn %s -> %s (%s)"%(self.pre_pop,self.post_pop, synapse))
-                    self.handler.handle_projection(proj_id, 
-                                         self.pre_pop, 
-                                         self.post_pop, 
+                    self.handler.handle_projection(proj_id,
+                                         self.pre_pop,
+                                         self.post_pop,
                                          synapse)
 
                     conn_count = 0
@@ -245,10 +245,10 @@ class PsyNeuLinkReader(NetworkReader):
                             #print("  Conn5 %s[%s] -> %s[%s]"%(self.pre_pop,i,self.post_pop,j))
                             delay = 1.111
                             weight =1
-                            self.handler.handle_connection(proj_id, 
-                                             conn_count, 
-                                             self.pre_pop, 
-                                             self.post_pop, 
+                            self.handler.handle_connection(proj_id,
+                                             conn_count,
+                                             self.pre_pop,
+                                             self.post_pop,
                                              synapse, \
                                              i, \
                                              j, \
@@ -257,9 +257,9 @@ class PsyNeuLinkReader(NetworkReader):
                             conn_count+=1
 
 
-                    self.handler.finalise_projection(proj_id, 
-                                         self.pre_pop, 
-                                         self.post_pop, 
+                    self.handler.finalise_projection(proj_id,
+                                         self.pre_pop,
+                                         self.post_pop,
                                          synapse)
 
             self.post_pop=None"""
